@@ -129,10 +129,10 @@ def log_shape(array):
 
 def with_object_array_or_scalar(f, field, obj_array_only=False):
     if obj_array_only:
-        if isinstance(field, numpy.ndarray) and numpy.dtype == object:
-	    ls = field.shape
-	else:
-	    ls = ()
+        if is_obj_array(field):
+            ls = field.shape
+        else:
+            ls = ()
     else:
         ls = log_shape(field)
     if ls != ():
@@ -162,3 +162,9 @@ def oarray_real(ary):
 
 def oarray_real_copy(ary):
     return with_object_array_or_scalar(lambda x: x.real.copy(), ary)
+
+
+
+
+def oarray_imag_copy(ary):
+    return with_object_array_or_scalar(lambda x: x.imag.copy(), ary)
